==> kubernetes-model-core-5.7.4-sources.jar: io/fabric8/kubernetes/api/model/SecretListBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SecretListBuilder extends io.fabric8.kubernetes.api.model.SecretListFluentImpl<io.fabric8.kubernetes.api.model.SecretListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.SecretList,io.fabric8.kubernetes.api.model.SecretListBuilder>{
  public SecretListBuilder() {
    this(false);
  }
  public SecretListBuilder(java.lang.Boolean validationEnabled) {
    this(new SecretList(), validationEnabled);
  }
  public SecretListBuilder(io.fabric8.kubernetes.api.model.SecretListFluent<?> fluent) {
    this(fluent, false);
  }
  public SecretListBuilder(io.fabric8.kubernetes.api.model.SecretListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SecretList(), validationEnabled);
  }
  public SecretListBuilder(io.fabric8.kubernetes.api.model.SecretListFluent<?> fluent,io.fabric8.kubernetes.api.model.SecretList instance) {
    this(fluent, instance, false);
  }
  public SecretListBuilder(io.fabric8.kubernetes.api.model.SecretListFluent<?> fluent,io.fabric8.kubernetes.api.model.SecretList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public SecretListBuilder(io.fabric8.kubernetes.api.model.SecretList instance) {
    this(instance,false);
  }
  public SecretListBuilder(io.fabric8.kubernetes.api.model.SecretList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.SecretListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.SecretList build() {
    SecretList buildable = new SecretList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretListBuilder that = (SecretListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/SecretListBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SecretListBuilder extends io.fabric8.kubernetes.api.model.SecretListFluentImpl<io.fabric8.kubernetes.api.model.SecretListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.SecretList,io.fabric8.kubernetes.api.model.SecretListBuilder>{
  public SecretListBuilder() {
    this(false);
  }
  public SecretListBuilder(java.lang.Boolean validationEnabled) {
    this(new SecretList(), validationEnabled);
  }
  public SecretListBuilder(io.fabric8.kubernetes.api.model.SecretListFluent<?> fluent) {
    this(fluent, false);
  }
  public SecretListBuilder(io.fabric8.kubernetes.api.model.SecretListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SecretList(), validationEnabled);
  }
  public SecretListBuilder(io.fabric8.kubernetes.api.model.SecretListFluent<?> fluent,io.fabric8.kubernetes.api.model.SecretList instance) {
    this(fluent, instance, false);
  }
  public SecretListBuilder(io.fabric8.kubernetes.api.model.SecretListFluent<?> fluent,io.fabric8.kubernetes.api.model.SecretList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SecretListBuilder(io.fabric8.kubernetes.api.model.SecretList instance) {
    this(instance,false);
  }
  public SecretListBuilder(io.fabric8.kubernetes.api.model.SecretList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.SecretListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.SecretList build() {
    SecretList buildable = new SecretList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretListBuilder that = (SecretListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
